@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:51:10
-@LastEditTime: 2022-07-11 14:09:26
+@LastEditTime: 2022-07-19 10:50:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -23,13 +23,14 @@ class AppExpireHandler(ClientBaseHandler):
         :return info
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
 
         app_base_model = AppBaseModel(context=self)
         invoke_result_data = app_base_model.get_app_expire(app_id)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params={}))
 
 
 class CreateWeChatQrCodeHandler(ClientBaseHandler):
@@ -66,7 +67,7 @@ class GetHighPowerListHandler(ClientBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_source_app_id()
+        app_id = self.get_app_id()
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
@@ -91,4 +92,4 @@ class GetHighPowerListHandler(ClientBaseHandler):
             custom_function_list = list(filter(lambda custom_function: custom_function["app_id"] == app_id, custom_function_list))
             if len(custom_function_list) > 0:
                 config_data["function_config_list"] = query(custom_function_list[0]["function_info_second_list"]).select(lambda x: {"name": x["name"], "key_name": x["key_name"]}).to_list()
-        self.response_json_success(config_data)
\ No newline at end of file
+        self.response_json_success(self.business_process_executed(config_data, ref_params={}))
