@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-01-07 10:56:16
+@LastEditTime: 2022-06-13 14:38:04
 @LastEditors: HuangJianYi
 @Description: 奖品模块
 """
@@ -18,7 +18,6 @@ class SaveActPrizeHandler(ClientBaseHandler):
     """
     :description: 保存活动奖品
     """
-    @filter_check_params("act_id")
     def post_async(self):
         """
         :description: 保存活动奖品
@@ -66,7 +65,7 @@ class SaveActPrizeHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         prize_id = int(self.get_param("prize_id", 0))
         prize_name = self.get_param("prize_name")
@@ -132,7 +131,6 @@ class ActPrizeListHandler(ClientBaseHandler):
     """
     :description: 活动奖品列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 活动奖品列表
@@ -147,7 +145,7 @@ class ActPrizeListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         prize_name = self.get_param("prize_name")
         is_del = int(self.get_param("is_del", -1))
@@ -267,7 +265,6 @@ class ActPrizeExportHandler(ClientBaseHandler):
     """
     :description: 导出活动奖品列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 导出活动奖品列表
@@ -282,7 +279,7 @@ class ActPrizeExportHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         prize_name = self.get_param("prize_name")
         is_del = int(self.get_param("is_del", -1))
