@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-05-12 16:13:55
+@LastEditTime: 2022-07-11 15:01:19
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -155,15 +155,16 @@ class WeChatHelper:
                 break
         if invoke_result_data.success == False:
             return invoke_result_data
+        access_token = invoke_result_data.data
         try:
-            requset_url = 'https://api.weixin.qq.com/cgi-bin/message/subscribe/send'
+            requset_url = 'https://api.weixin.qq.com/cgi-bin/message/subscribe/send?access_token=' + access_token
             param = {
                 "touser": open_id,
                 "page": page,
                 "lang": lang,
                 "data": request_data,
-                "templateId": template_id,
-                "miniprogramState": miniprogram_state
+                "template_id": template_id,
+                "miniprogram_state": miniprogram_state
                 }
             response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers={'Content-Type': 'application/json'})
             response_data = SevenHelper.json_loads(response.text)
@@ -327,7 +328,7 @@ class WeChatHelper:
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error("【decrypt_data】" + traceback.format_exc())
+            ("【decrypt_data】" + traceback.format_exc())
         return data
 
     @classmethod
