@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2022-07-25 15:26:05
+@LastEditTime: 2022-08-31 15:04:42
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -183,11 +183,10 @@ class AssetBaseModel():
                 #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                 self._add_onlyid_warn_stat(handler_name)
                 return invoke_result_data
-        frame_base_model = FrameBaseModel(context=self.context)
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_asset_model = UserAssetModel(db_transaction=db_transaction, sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"act_id":act_id,"user_id":0}), context=self.context)
-        asset_log_model = AssetLogModel(db_transaction=db_transaction, sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
-        asset_only_model = AssetOnlyModel(db_transaction=db_transaction, sub_table=frame_base_model.get_business_sub_table("asset_only_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
+        user_asset_model = UserAssetModel(db_transaction=db_transaction, context=self.context)
+        asset_log_model = AssetLogModel(db_transaction=db_transaction, context=self.context)
+        asset_only_model = AssetOnlyModel(db_transaction=db_transaction, context=self.context)
 
         acquire_lock_name = f"userasset:{user_asset_id_md5}"
         acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
@@ -369,8 +368,7 @@ class AssetBaseModel():
             else:
                 condition += " AND user_id=%s"
                 params.append(user_ids)
-        frame_base_model = FrameBaseModel(context=self.context) 
-        user_asset_model = UserAssetModel(sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"act_id":act_id,"user_id":0}), context=self.context)
+        user_asset_model = UserAssetModel(context=self.context)
         user_asset_dict_list = user_asset_model.get_dict_list(condition, params=params)
         if len(user_asset_dict_list) > 0:
             for user_asset_dict in user_asset_dict_list:
@@ -394,8 +392,7 @@ class AssetBaseModel():
         """
         if not act_id or not user_id or not asset_type:
             return None
-        frame_base_model = FrameBaseModel(context=self.context) 
-        user_asset_model = UserAssetModel(sub_table=frame_base_model.get_business_sub_table("user_asset_tb",{"act_id":act_id,"user_id":0}), context=self.context)
+        user_asset_model = UserAssetModel(context=self.context)
         user_asset_id_md5 = self.get_user_asset_id_md5(act_id, user_id, asset_type, asset_object_id)
         user_asset_dict = user_asset_model.get_dict("id_md5=%s", limit="1", params=[user_asset_id_md5])
         if user_asset_dict:
@@ -473,8 +470,7 @@ class AssetBaseModel():
             else:
                 condition += " AND source_object_id=%s"
                 params.append(source_object_id)
-        frame_base_model = FrameBaseModel(context=self.context)
-        asset_log_model = AssetLogModel(sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
+        asset_log_model = AssetLogModel(context=self.context)
         if is_cache:
             page_list, total = asset_log_model.get_cache_dict_page_list(field, page_index, page_size, condition, order_by="create_date desc", params=params,dependency_key=DependencyKey.asset_log_list(act_id,user_id))
         else:
@@ -486,7 +482,7 @@ class AssetBaseModel():
                 item["create_day"] = TimeHelper.format_time_to_datetime(str(item["create_date"])).strftime('%Y-%m-%d')
         return page_list,total
 
-    def add_asset_log(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, sub_table=None, history_asset_value=0, handler_name="", request_code="", info_json={}):
+    def add_asset_log(self, app_id, act_id, module_id, user_id, open_id, user_nick, asset_type, asset_value, asset_object_id, source_type, source_object_id, source_object_name, log_title, history_asset_value=0, handler_name="", request_code="", info_json={}):
         """
         :description: 添加资产流水
         :param act_id：活动标识
@@ -501,7 +497,6 @@ class AssetBaseModel():
         :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
         :param source_object_name：来源对象名称(比如来源类型是任务则对应任务名称)
         :param log_title：资产流水标题
-        :param sub_table：资产流水分表名
         :param history_asset_value:历史资产值
         :param handler_name:接口名称
         :param request_code:请求唯一标识，从seven_framework框架获取对应request_code
@@ -510,11 +505,7 @@ class AssetBaseModel():
         :last_editors: HuangJianYi
         """
         asset_value = int(asset_value)
-        if sub_table:
-            asset_log_model = AssetLogModel(sub_table=sub_table, context=self.context)
-        else:
-            frame_base_model = FrameBaseModel(context=self.context)
-            asset_log_model = AssetLogModel(sub_table=frame_base_model.get_business_sub_table("asset_log_tb",{"act_id":act_id,"user_id":user_id}), context=self.context)
+        asset_log_model = AssetLogModel(context=self.context)
         asset_log = AssetLog()
         asset_log.app_id = app_id
         asset_log.act_id = act_id
