@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-07-20 11:28:03
+@LastEditTime: 2022-09-08 16:21:23
 @LastEditors: HuangJianYi
 @Description: 
 """
+from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest
 from seven_cloudapp_frame.models.user_base_model import UserBaseModel
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.seven_model import *
@@ -19,6 +20,8 @@ from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_pay_order_model import *
 from seven_cloudapp_frame.models.db_models.user.user_info_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_coupon_model import *
+from seven_cloudapp_frame.models.db_models.pay.pay_order_model import *
+from seven_cloudapp_frame.models.db_models.refund.refund_order_model import *
 
 
 class OrderBaseModel(FrameBaseModel):
@@ -40,7 +43,7 @@ class OrderBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(DependencyKey.prize_order_list(act_id,user_id), delay_delete_time)
+        PrizeOrderModel().delete_dependency_key(DependencyKey.prize_order_list(act_id,user_id), delay_delete_time)
         
     def _delete_prize_roster_dependency_key(self, act_id, user_id, delay_delete_time=0.1):
         """
@@ -51,7 +54,7 @@ class OrderBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id), delay_delete_time)
+        PrizeRosterModel().delete_dependency_key(DependencyKey.prize_roster_list(act_id,user_id), delay_delete_time)
 
     def get_prize_order_list(self, app_id, act_id, user_id, open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size=20, page_index=0, order_by="create_date desc", field="*", is_search_roster=False, is_cache=True, condition="", params=[], prize_roster_sub_table=None):
         """
@@ -121,14 +124,12 @@ class OrderBaseModel(FrameBaseModel):
         if create_date_end:
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
-        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        prize_order_model = PrizeOrderModel(context=self.context)
         if is_cache:
             page_list, total = prize_order_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, DependencyKey.prize_order_list(act_id,user_id))
         else:
             page_list, total = prize_order_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         if is_search_roster == True:
-            if not prize_roster_sub_table:
-                prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
             prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
             if page_list and len(page_list)>0:
                 order_no_list = [str(i['order_no']) for i in page_list]
@@ -151,11 +152,9 @@ class OrderBaseModel(FrameBaseModel):
         :return: 实体模型InvokeResultData
         :last_editors: HuangJianYi
         """
-        if not prize_roster_sub_table:
-            prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
         now_datetime = SevenHelper.get_now_datetime()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context, db_transaction=db_transaction)
+        prize_order_model = PrizeOrderModel(context=self.context, db_transaction=db_transaction)
         prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table, db_transaction=db_transaction)
         invoke_result_data = InvokeResultData()
 
@@ -170,6 +169,11 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="奖品订单信息不存在-2"
             return invoke_result_data
+        if prize_order.act_id != act_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-3"
+            return invoke_result_data
         try:
             db_transaction.begin_transaction()
             if order_status == 1:
@@ -218,7 +222,7 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         now_datetime = SevenHelper.get_now_datetime()
-        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        prize_order_model = PrizeOrderModel(context=self.context)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -227,11 +231,16 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="奖品订单信息不存在-1"
             return invoke_result_data
-        if prize_order.app_id!=app_id:
+        if prize_order.app_id != app_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="奖品订单信息不存在-2"
             return invoke_result_data
+        if prize_order.act_id != act_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-3"
+            return invoke_result_data
         prize_order_model.update_table("seller_remark=%s,modify_date=%s", "id=%s", [seller_remark, now_datetime, prize_order_id])
         return invoke_result_data
     
@@ -253,7 +262,7 @@ class OrderBaseModel(FrameBaseModel):
         """
 
         now_datetime = SevenHelper.get_now_datetime()
-        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        prize_order_model = PrizeOrderModel(context=self.context)
         invoke_result_data = InvokeResultData()
 
         prize_order = prize_order_model.get_entity_by_id(prize_order_id)
@@ -267,6 +276,11 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="奖品订单信息不存在-2"
             return invoke_result_data
+        if prize_order.act_id != act_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-3"
+            return invoke_result_data
         if province != None:
             prize_order.province = province
         if city != None:
@@ -302,8 +316,6 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
-        if not prize_roster_sub_table:
-            prize_roster_sub_table = self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0})
         prize_order_model = PrizeOrderModel(context=self.context)
         prize_roster_model = PrizeRosterModel(context=self.context, sub_table=prize_roster_sub_table)
         data = []
@@ -400,9 +412,9 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="无效活动,无法创建订单"
             return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_info_model = UserInfoModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
-        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
-        prize_order_model = PrizeOrderModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
+        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
+        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction, context=self.context)
+        prize_order_model = PrizeOrderModel(db_transaction=db_transaction, context=self.context)
         prize_ids_list = []
         if prize_ids:
             prize_ids_list = prize_ids.split(',')
@@ -453,7 +465,7 @@ class OrderBaseModel(FrameBaseModel):
         else:
             prize_roster_list = prize_roster_model.get_list("act_id=%s and prize_status=0")
 
-        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        prize_order_model = PrizeOrderModel(context=self.context)
         now_date = SevenHelper.get_now_datetime()
         prize_order = PrizeOrder()
         prize_order.app_id = app_id
@@ -841,7 +853,7 @@ class OrderBaseModel(FrameBaseModel):
             where += " AND create_date<=%s"
             params_list.append(create_date_end)
 
-        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        prize_roster_model = PrizeRosterModel(context=self.context)
         if is_cache:
             page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list,DependencyKey.prize_roster_list(act_id,user_id))
         else:
@@ -876,7 +888,7 @@ class OrderBaseModel(FrameBaseModel):
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
                 condition_where.add_condition("prize_id not in (" + prize_ids + ")")
-        prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        prize_roster_model = PrizeRosterModel(context=self.context)
         prize_roster_list = prize_roster_model.get_cache_dict_list(condition_where.to_string(), "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,module_name", params_list, cache_expire=60)
         total = int(len(prize_roster_list))
         if total == 0:
@@ -911,7 +923,7 @@ class OrderBaseModel(FrameBaseModel):
             false_act_prize_list = act_prize_model.get_cache_list(prize_condition, order_by="probability desc,chance desc", limit="30", params=prize_params,cache_expire=60)
             if len(false_act_prize_list) > 0 and add_num > 0:
                 now_datetime = TimeHelper.add_hours_by_format_time(hour=-random.randint(0, 1000))
-                user_info_list_dict = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
+                user_info_list_dict = UserInfoModel(context=self.context).get_dict_list("act_id<%s and create_date>%s", params=[act_id,now_datetime], limit=str(add_num))
 
                 for i in range(len(user_info_list_dict)):
                     false_act_prize = false_act_prize_list[random.randint(0, len(false_act_prize_list)-1)]
@@ -934,19 +946,21 @@ class OrderBaseModel(FrameBaseModel):
 
         return prize_roster_list
 
-    def get_coupon_prize(self, app_id, act_id, user_id, user_prize_id,is_log=False):
+    def get_coupon_prize(self, app_id, act_id, user_id, user_prize_id, app_key, app_secret, is_log=False):
         """
         :description: 领取淘宝优惠券
         :param app_id：应用标识
         :param act_id：活动标识
         :param user_id：用户标识
         :param user_prize_id:用户奖品标识
+        :param app_key:app_key
+        :param app_secret:app_secret
         :param is_log:是否记录日志
         :return 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        app_base_model = AppBaseModel(context=self)
+        app_base_model = AppBaseModel(context=self.context)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
             invoke_result_data.success = False
@@ -960,23 +974,21 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.error_message ="未授权请联系客服授权"
             return invoke_result_data
         dependency_key = f"prize_roster_list:actid_{act_id}_userid_{user_id}"
-        frame_base_model = FrameBaseModel(context=self)
-        prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"act_id": act_id, "user_id": 0}), context=self)
+        prize_roster_model = PrizeRosterModel(context=self.context)
         prize_roster_dict = prize_roster_model.get_cache_dict_by_id(user_prize_id, dependency_key=dependency_key)
         if not prize_roster_dict or prize_roster_dict['user_id'] != user_id or prize_roster_dict['act_id'] != act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="奖品不存在"
             return invoke_result_data
-        tao_coupon_model = TaoCouponModel(context=self)
+        tao_coupon_model = TaoCouponModel(context=self.context)
         tao_coupon_dict = tao_coupon_model.get_dict(where="prize_id=%s", limit="1", params=[prize_roster_dict["prize_id"]])
         if not tao_coupon_dict or tao_coupon_dict['right_ename'] == "":
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="奖品不是优惠券,无需领取"
             return invoke_result_data
-        top_base_model = TopBaseModel(context=self)
-        app_key,app_secret = self.get_app_key_secret()
+        top_base_model = TopBaseModel(context=self.context)
         top_invoke_result_data = top_base_model.alibaba_benefit_send(tao_coupon_dict['right_ename'], prize_roster_dict["open_id"], access_token, app_key, app_secret, is_log)
         if top_invoke_result_data.success == False:
             invoke_result_data.success = False
@@ -999,6 +1011,11 @@ class OrderBaseModel(FrameBaseModel):
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message ="领取失败：优惠券无效或已删除"
                 return invoke_result_data
+            if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_NOT_EXISTS":
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="领取失败：优惠券不存在"
+                return invoke_result_data
             if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_SINGLE_COUPON_COUNT_EXCEED_LIMIT":
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
@@ -1014,6 +1031,12 @@ class OrderBaseModel(FrameBaseModel):
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message ="领取失败：用户优惠券超出10张限制"
                 return invoke_result_data
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="领取失败"
+            invoke_result_data.data = resp["alibaba_benefit_send_response"]["result_code"]
+            return invoke_result_data
+            
         else:
             result = resp["sub_msg"] if resp["sub_msg"] else ""
             if result == "" and resp["result_msg"]:
@@ -1021,4 +1044,94 @@ class OrderBaseModel(FrameBaseModel):
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = f"领取失败:{result}"
-            return invoke_result_data
\ No newline at end of file
+            return invoke_result_data
+
+    def create_wechat_refund(self, source_type, app_id, act_id, pay_order_no, refund_amount = 0, refund_reason = ""):
+        """
+        :description: 创建微信退款
+        :param source_type：来源类型（1用户申请退款2人工审核退款3自动退款）
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param pay_order_no：支付单号
+        :param refund_reason：退款原因
+        :return 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        pay_order_model = PayOrderModel(context=self)
+        refund_order_model = RefundOrderModel(context=self)
+        #请求太频繁限制
+        if SevenHelper.is_continue_request(f"create_wechat_refund:{app_id}_{pay_order_no}", 1000) == False:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="请求太频繁,请稍后再试"
+            return invoke_result_data
+
+        pay_order = pay_order_model.get_entity("pay_order_no=%s", params=pay_order_no)
+        if not pay_order:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="对不起，找不到支付订单"
+            return invoke_result_data
+
+        refund_order = refund_order_model.get_entity(where="pay_order_no=%s AND refund_status in (1,2)", params=[pay_order_no])
+        if refund_order:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="对不起，退款处理中"
+            return invoke_result_data
+        if refund_amount <= 0:
+            refund_amount = pay_order.pay_amount
+        if pay_order.refund_amount + refund_amount > pay_order.pay_amount:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="退款总金额不能超过支付金额"
+            return invoke_result_data
+            
+        refund_status = 0
+        if source_type == 1:
+            refund_reason = refund_reason
+            refund_status = 1
+        elif source_type == 2:
+            refund_reason = "人工审核退款"
+        elif source_type == 3:
+            refund_reason = "自动退款"
+        
+        
+        refund_no = SevenHelper.create_order_id()
+        #创建退款预订单
+        refund_order = RefundOrder()
+        refund_order.app_id = app_id
+        refund_order.act_id = act_id
+        refund_order.user_id = pay_order.user_id
+        refund_order.open_id = pay_order.open_id
+        refund_order.pay_order_no = pay_order_no
+        refund_order.refund_no = refund_no
+        refund_order.out_order_no = pay_order.out_order_no
+        refund_order.refund_amount = refund_amount
+        refund_order.refund_status = refund_status
+        refund_order.refund_reason = refund_reason
+        refund_order.create_date = SevenHelper.get_now_datetime()
+        refund_order.id = refund_order_model.add_entity(refund_order)
+        if refund_order.id <= 0:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="对不起，创建退款订单失败"
+            return invoke_result_data
+        
+        if source_type != 1:
+            wechat_pay = config.get_value("wechat_pay")
+            #退款异步通知地址
+            notify_url = wechat_pay["notify_url"]
+            result_data = WeChatPayRequest().create_refund(refund_no, pay_order.pay_order_no, notify_url, refund_amount, pay_order.pay_amount)
+            if result_data.success == False:
+                refund_order_model.del_entity("id=%s", params=refund_order.id)
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message ="对不起，创建退款订单异常"
+                return invoke_result_data
+            refund_order_model.update_table("refund_status=2", "id=%s", params=refund_order.id)
+            invoke_result_data.data = refund_no
+
+        return invoke_result_data
+    
\ No newline at end of file
