@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-07-22 11:48:40
+@LastEditTime: 2022-08-16 14:13:05
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -62,7 +62,7 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0})).delete_dependency_key(DependencyKey.user_info(act_id, id_md5),delay_delete_time)
+        UserInfoModel().delete_dependency_key(DependencyKey.user_info(act_id, id_md5),delay_delete_time)
 
     def get_user_info_dict(self, app_id, act_id, user_id, open_id="", is_cache=True):
         """
@@ -77,7 +77,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_dict = None
         if not act_id or (not user_id and not open_id):
             return user_info_dict
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context)
         id_md5 = self._get_user_info_id_md5(act_id, user_id)
         dependency_key = DependencyKey.user_info(act_id, id_md5, open_id)
         if id_md5:
@@ -138,7 +138,7 @@ class UserBaseModel(FrameBaseModel):
         if end_date:
             condition += " AND create_date<=%s"
             params.append(end_date)
-        page_list, total = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
+        page_list, total = UserInfoModel(context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
@@ -182,10 +182,11 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "acquire_lock"
             invoke_result_data.error_message = "请求超时,请稍后再试"
             return invoke_result_data
-
+        
+        user_account = None
         user_account_model = UserAccountModel(context=self.context)
         user_info = None
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context)
         now_datetime = SevenHelper.get_now_datetime()
         try:
             user_account = user_account_model.get_entity("open_id=%s", params=[open_id])
@@ -260,8 +261,13 @@ class UserBaseModel(FrameBaseModel):
                 self.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
         finally:
             SevenHelper.redis_release_lock(acquire_lock_name, identifier)
-
-        invoke_result_data.data = user_info.__dict__
+         
+        user_info_dict = user_info.__dict__
+        if user_info_dict:
+            user_info_dict["telephone"] = user_account.telephone if user_account else ""
+            user_info_dict["sex"] = user_account.sex if user_account else 0
+            user_info_dict["birthday"] = user_account.birthday if user_account and user_account.birthday != "1900-01-01" else ""
+        invoke_result_data.data = user_info_dict
         return invoke_result_data
 
     def update_user_info(self, app_id, act_id, user_id, open_id, user_nick, avatar, is_member_before=-1, is_favor_before=-1):
@@ -288,7 +294,7 @@ class UserBaseModel(FrameBaseModel):
 
         user_account_model = UserAccountModel(context=self.context)
         user_info_dict = None
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context)
 
         try:
             user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
@@ -350,7 +356,7 @@ class UserBaseModel(FrameBaseModel):
         """
         invoke_result_data = InvokeResultData()
         id_md5 = self._get_user_info_id_md5(act_id, user_id)
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context)
         user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
@@ -390,7 +396,7 @@ class UserBaseModel(FrameBaseModel):
         """
         invoke_result_data = InvokeResultData()
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_info_model = UserInfoModel(db_transaction=db_transaction,sub_table=self.get_business_sub_table("user_info_tb", {"act_id": act_id, "user_id": 0}), context=self.context)
+        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
 
         user_info_dict = self.get_user_info_dict(app_id, act_id, user_id)
@@ -536,7 +542,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
 
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": user_black.act_id, "user_id": 0}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context)
         id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id)
         user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
@@ -701,7 +707,7 @@ class UserBaseModel(FrameBaseModel):
                 #超过变成黑用户
                 if len(refund_order_data) >= refund_count:
                     result = True
-                    user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb", {"act_id": user_info_dict["act_id"], "user_id": 0}),context=self.context)
+                    user_info_model = UserInfoModel(context=self.context)
                     user_info_model.update_table("user_state=1", "id=%s", user_info_dict["id"])
                     user_black_model = UserBlackModel(context=self.context)
                     user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[user_info_dict["act_id"], user_info_dict["user_id"]])
